package net.minecraft.src.forestry.api;

import net.minecraft.src.ItemStack;

/**
 * Provides an interface to the recipe manager of the still. 
 *
 * The manager is initialized at the beginning of Forestry's BaseMod.load() cycle.
 * Begin adding recipes in BaseMod.ModsLoaded() and this shouldn't be null even if
 * your mod loads before Forestry.
 * 
 * Accessible via {@link ForestryAPI.stillManager}
 *
 * Note that this is untested with anything other than biomass->biofuel conversion.
 *
 * @author SirSengir
 */
public interface IStillManager {
	/**
	 * Add a recipe to the still
	 * @param cyclesPerUnit Amount of work cycles required to run through the conversion once.
	 * @param input ItemStack representing the input liquid.
	 * @param inputAmount Amount of liquid required for a single conversion.
	 * @param output ItemStack representing the output liquid
	 * @param outputAmount Amount of liquid output by a single conversion.
	 */
	public void addRecipe(int cyclesPerUnit, ItemStack input, int inputAmount, ItemStack output, int outputAmount);
}
